0.9.9 API documentation: common.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

gtx/common.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependencies:
16 #include "../vec2.hpp"
17 #include "../vec3.hpp"
18 #include "../vec4.hpp"
19 #include "../gtc/vec1.hpp"
20
21 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
22 # ifndef GLM_ENABLE_EXPERIMENTAL
23 # pragma message("GLM: GLM_GTX_common is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
24 # else
25 # pragma message("GLM: GLM_GTX_common extension included")
26 # endif
27 #endif
28
29 namespace glm
30 {
33
42 template<typename genType>
43 GLM_FUNC_DECL typename genType::bool_type isdenormal(genType const& x);
44
50 template<length_t L, typename T, qualifier Q>
51 GLM_FUNC_DECL vec<L, T, Q> fmod(vec<L, T, Q> const& v);
52
60 template <length_t L, typename T, qualifier Q>
61 GLM_FUNC_DECL vec<L, bool, Q> openBounded(vec<L, T, Q> const& Value, vec<L, T, Q> const& Min, vec<L, T, Q> const& Max);
62
70 template <length_t L, typename T, qualifier Q>
71 GLM_FUNC_DECL vec<L, bool, Q> closeBounded(vec<L, T, Q> const& Value, vec<L, T, Q> const& Min, vec<L, T, Q> const& Max);
72
74 }//namespace glm
75
76 #include "common.inl"
glm::fmod
GLM_FUNC_DECL vec< L, T, Q > fmod(vec< L, T, Q > const &v)
Similar to 'mod' but with a different rounding and integer support.
glm::openBounded
GLM_FUNC_DECL vec< L, bool, Q > openBounded(vec< L, T, Q > const &Value, vec< L, T, Q > const &Min, vec< L, T, Q > const &Max)
Returns whether vector components values are within an interval.
glm::isdenormal
GLM_FUNC_DECL genType::bool_type isdenormal(genType const &x)
Returns true if x is a denormalized number Numbers whose absolute value is too small to be represente...
glm
Definition: common.hpp:20
glm::closeBounded
GLM_FUNC_DECL vec< L, bool, Q > closeBounded(vec< L, T, Q > const &Value, vec< L, T, Q > const &Min, vec< L, T, Q > const &Max)
Returns whether vector components values are within an interval.